@@ -17,7 +17,8 @@ def callback():
 
 def get_template_path(template_name):
     script_path = os.path.abspath(__file__)
-    templates_path = os.path.join(script_path, "templates")
+    module_path = os.path.dirname(script_path)
+    templates_path = os.path.join(module_path, "templates")
     return os.path.join(templates_path, template_name)
     
 
